#ifndef IMAGEIO_H
#define IMAGEIO_H
/*
Szymon Rusinkiewicz
Princeton University

imageio.h
Simple wrapper for JPEG and PNG libraries for image input and output.
*/

#include <stdbool.h>


/* Structure defining color at a pixel: R, G, and B as unsigned char */
typedef struct {
	unsigned char r, g, b;
} Color;


/* Structure defining an image: width, height, and pixels */
typedef struct {
	int w, h;
	Color *pixels;
} Im;


/* Allocate a new Im of the given width and height.  Zero-initialized. */
Im *Im_alloc(int w, int h);

/* Read an Im from a file.  Returns NULL if it can't. */
Im *Im_read(const char *filename);

/* Write an Im to a file.  Returns true if write succeded, else false. */
bool Im_write(const Im *im, const char *filename);

/* Free storage corresponding to an Im. */
void Im_free(Im *im);

/* Access a pixel in an image by (x,y) coordinate.  *No* bounds checking. */
static inline Color *Im_pixel(Im *im, int x, int y)
{
	return &im->pixels[x + y * im->w];
}

/* Set a pixel in an image to a given r,g,b color.  *No* bounds checking. */
static void Im_set(Im *im, int x, int y,
	unsigned char r, unsigned char g, unsigned char b)
{
	Color *pix = Im_pixel(im, x, y);
	pix->r = r;
	pix->g = g;
	pix->b = b;
}

#endif
